window.Gleam.initSearch([{"doc":"flash","title":"flash","content":"# flash\n\n[![Package Version](https://img.shields.io/hexpm/v/flash)](https://hex.pm/packages/flash)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/flash/)\n[![License](https://img.shields.io/badge/License-BSD_2--Clause_+_Patent-blue.svg)](https://github.com/larzconwell/flash/blob/main/LICENSE)\n[![Test](https://github.com/larzconwell/flash/actions/workflows/test.yml/badge.svg)](https://github.com/larzconwell/flash/actions)\n\n`flash` is a Gleam package enabling structured logging in both Erlang and JavaScript environments.\n\n## Usage\n\n```\ngleam add flash\n```\n\nWith the default text writer output:\n```gleam\nimport flash.{InfoLevel, GroupAttr, StringAttr}\n\npub fn main() {\n  flash.new(InfoLevel, flash.text_writer)\n  |&gt; flash.with_group(&quot;request&quot;)\n  |&gt; flash.with_attrs([\n    StringAttr(&quot;method&quot;, &quot;POST&quot;),\n    StringAttr(&quot;path&quot;, &quot;/user/create&quot;),\n    StringAttr(&quot;id&quot;, &quot;foobar&quot;),\n  ])\n  |&gt; flash.info(&quot;request&quot;)\n}\n```\n\n```\n21:24:12 INFO  request                                       request.id=foobar request.method=POST request.path=/user/create\n```\n\nWith the default json writer output:\n```gleam\nimport flash.{InfoLevel, GroupAttr, StringAttr}\n\npub fn main() {\n  flash.new(InfoLevel, flash.json_writer)\n  |&gt; flash.with_group(&quot;request&quot;)\n  |&gt; flash.with_attrs([\n    StringAttr(&quot;method&quot;, &quot;POST&quot;),\n    StringAttr(&quot;path&quot;, &quot;/user/create&quot;),\n    StringAttr(&quot;id&quot;, &quot;foobar&quot;),\n  ])\n  |&gt; flash.info(&quot;request&quot;)\n}\n```\n\n```\n{&quot;level&quot;:&quot;info&quot;,&quot;time&quot;:&quot;2024-03-12T21:25:03.022-04:00&quot;,&quot;message&quot;:&quot;request&quot;,&quot;request&quot;:{&quot;id&quot;:&quot;foobar&quot;,&quot;method&quot;:&quot;POST&quot;,&quot;path&quot;:&quot;/user/create&quot;}}\n```\n\n## Developing\n\n```shell\nln -s $(pwd)/.hooks/pre-commit .git/hooks/pre-commit\ngleam format\ngleam build\ngleam test\n```\n","url":"index.html"},{"doc":"flash","title":"Attr","content":"pub type Attr {\n  BoolAttr(key: String, value: Bool)\n  FloatAttr(key: String, value: Float)\n  GroupAttr(key: String, value: List(Attr))\n  IntAttr(key: String, value: Int)\n  StringAttr(key: String, value: String)\n}\n Collection of typed attributes to add data to loggers.\nBoolAttr(key: String, value: Bool)\n\n\nFloatAttr(key: String, value: Float)\n\n\nGroupAttr(key: String, value: List(Attr))\n\n\nIntAttr(key: String, value: Int)\n\n\nStringAttr(key: String, value: String)\n\n\nSynonyms:\nflash.Attr\nflash Attr","url":"flash.html#Attr"},{"doc":"flash","title":"Level","content":"pub type Level {\n  DebugLevel\n  InfoLevel\n  WarnLevel\n  ErrorLevel\n}\n Available log levels, where debug is the lowest level and error is the highest level.\nDebugLevel\n\n\nInfoLevel\n\n\nWarnLevel\n\n\nErrorLevel\n\n\nSynonyms:\nflash.Level\nflash Level","url":"flash.html#Level"},{"doc":"flash","title":"Logger","content":"pub type Logger {\n  Logger(\n    level: Level,\n    writer: Writer,\n    parent: Option(Logger),\n    group: String,\n    attrs: List(Attr),\n  )\n}\n\nLogger(\n  level: Level,\n  writer: Writer,\n  parent: Option(Logger),\n  group: String,\n  attrs: List(Attr),\n)\n\n\nSynonyms:\nflash.Logger\nflash Logger","url":"flash.html#Logger"},{"doc":"flash","title":"Writer","content":"pub type Writer =\n  fn(Level, String, List(Attr)) -&gt; Nil\n Function type for custom writer implementations.\n\nSynonyms:\nflash.Writer\nflash Writer","url":"flash.html#Writer"},{"doc":"flash","title":"default","content":"pub const default: Logger = Logger(\n  InfoLevel,\n  text_writer,\n  None,\n  &quot;&quot;,\n  [],\n)\n Default logger that omits debug level logs and outputs a text format.\nSynonyms:\nflash.default\nflash default","url":"flash.html#default"},{"doc":"flash","title":"debug","content":"pub fn debug(logger: Logger, message: String) -&gt; Nil\n Logs the message and any attributes at the debug level.\nSynonyms:\nflash.debug\nflash debug","url":"flash.html#debug"},{"doc":"flash","title":"enabled","content":"pub fn enabled(logger: Logger, level: Level) -&gt; Bool\n Determines if the logger is enabled for the given log level.\nSynonyms:\nflash.enabled\nflash enabled","url":"flash.html#enabled"},{"doc":"flash","title":"error","content":"pub fn error(logger: Logger, message: String) -&gt; Nil\n Logs the message and any attributes at the error level.\nSynonyms:\nflash.error\nflash error","url":"flash.html#error"},{"doc":"flash","title":"info","content":"pub fn info(logger: Logger, message: String) -&gt; Nil\n Logs the message and any attributes at the info level.\nSynonyms:\nflash.info\nflash info","url":"flash.html#info"},{"doc":"flash","title":"json_writer","content":"pub fn json_writer(\n  level: Level,\n  message: String,\n  attrs: List(Attr),\n) -&gt; Nil\n A writer that writes to standard out using a JSON representation.\n Here&#39;s some example code and the associated JSON output:\n\n \n let logger = with_attr(logger, StringAttr(&quot;request_id&quot;, &quot;foobar&quot;))\n info(logger, &quot;/health&quot;)\n \n\n \n {&quot;level&quot;:&quot;info&quot;,&quot;time&quot;:&quot;2024-03-09T12:52:43.657-05:00&quot;,&quot;message&quot;:&quot;/health&quot;,&quot;request_id&quot;:&quot;foobar&quot;}\n \n\n The `level`, `time`, and `message` attributes are added automatically and will be\n ordered before other attributes. Other attributes are sorted lexicographically with\n groups being sorted after non group attributes. If multiple attributes in the same\n group share a key, the last attribute with the key is chosen.\nSynonyms:\nflash.json_writer\nflash json_writer","url":"flash.html#json_writer"},{"doc":"flash","title":"level_to_string","content":"pub fn level_to_string(level: Level) -&gt; String\n Converts a level variant to an equivalent string representation.\nSynonyms:\nflash.level_to_string\nflash level_to_string","url":"flash.html#level_to_string"},{"doc":"flash","title":"log","content":"pub fn log(logger: Logger, level: Level, message: String) -&gt; Nil\n Logs the message and any attributes if the logger is enabled to\n log at the given log level.\nSynonyms:\nflash.log\nflash log","url":"flash.html#log"},{"doc":"flash","title":"new","content":"pub fn new(\n  level: Level,\n  writer: fn(Level, String, List(Attr)) -&gt; Nil,\n) -&gt; Logger\n Creates a logger that logs for levels greater than or equal to\n the given level and writes using the given writer.\nSynonyms:\nflash.new\nflash new","url":"flash.html#new"},{"doc":"flash","title":"parse_level","content":"pub fn parse_level(level: String) -&gt; Result(Level, Nil)\n Parses a string representation of a level to the equivalent level variant.\nSynonyms:\nflash.parse_level\nflash parse_level","url":"flash.html#parse_level"},{"doc":"flash","title":"text_writer","content":"pub fn text_writer(\n  level: Level,\n  message: String,\n  attrs: List(Attr),\n) -&gt; Nil\n A writer that writes to standard out using a text representation.\n Here&#39;s some example code and the associated text output:\n\n \n let logger = with_attr(logger, StringAttr(&quot;request_id&quot;, &quot;foobar&quot;))\n info(logger, &quot;/health&quot;)\n \n\n \n 12:59:37 INFO  /health                                       request_id=foobar\n \n\n Attributes are sorted lexicographically with groups being sorted after non\n group attributes. If multiple attributes in the same group share a key, the\n last attribute with the key is chosen.\nSynonyms:\nflash.text_writer\nflash text_writer","url":"flash.html#text_writer"},{"doc":"flash","title":"warn","content":"pub fn warn(logger: Logger, message: String) -&gt; Nil\n Logs the message and any attributes at the warn level.\nSynonyms:\nflash.warn\nflash warn","url":"flash.html#warn"},{"doc":"flash","title":"with_attr","content":"pub fn with_attr(logger: Logger, attr: Attr) -&gt; Logger\n Adds the given attribute to the logger.\nSynonyms:\nflash.with_attr\nflash with_attr","url":"flash.html#with_attr"},{"doc":"flash","title":"with_attrs","content":"pub fn with_attrs(logger: Logger, attrs: List(Attr)) -&gt; Logger\n Adds the list of attributes to the logger.\nSynonyms:\nflash.with_attrs\nflash with_attrs","url":"flash.html#with_attrs"},{"doc":"flash","title":"with_group","content":"pub fn with_group(logger: Logger, group: String) -&gt; Logger\n Creates a child group from the given logger with the given group name.\nSynonyms:\nflash.with_group\nflash with_group","url":"flash.html#with_group"},{"doc":"flash","title":"flash","content":"","url":"flash.html"}]);